==> apache-storm-1.1.2-src.zip: apache-storm-1.1.2/external/storm-elasticsearch/src/main/java/org/apache/storm/elasticsearch/common/EsTupleMapper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.storm.elasticsearch.common;

import org.apache.storm.tuple.ITuple;

import java.io.Serializable;

/**
 * TupleMapper defines how to extract source, index, type, and id from tuple for ElasticSearch.
 */
public interface EsTupleMapper extends Serializable {
    /**
     * Extracts source from tuple.
     * @param tuple source tuple
     * @return source
     */
    String getSource(ITuple tuple);

    /**
     * Extracts index from tuple.
     * @param tuple source tuple
     * @return index
     */
    String getIndex(ITuple tuple);

    /**
     * Extracts type from tuple.
     * @param tuple source tuple
     * @return type
     */
    String getType(ITuple tuple);

    /**
     * Extracts id from tuple.
     * @param tuple source tuple
     * @return id
     */
    String getId(ITuple tuple);
}

==> apache-storm-1.2.4-src.zip: apache-storm-1.2.4/external/storm-elasticsearch/src/main/java/org/apache/storm/elasticsearch/common/EsTupleMapper.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.storm.elasticsearch.common;

import org.apache.storm.tuple.ITuple;

import java.io.Serializable;
import java.util.Map;

/**
 * TupleMapper defines how to extract source, index, type, and id from tuple for ElasticSearch.
 */
public interface EsTupleMapper extends Serializable {
    /**
     * Extracts source from tuple.
     * @param tuple source tuple
     * @return source
     */
    String getSource(ITuple tuple);

    /**
     * Extracts index from tuple.
     * @param tuple source tuple
     * @return index
     */
    String getIndex(ITuple tuple);

    /**
     * Extracts type from tuple.
     * @param tuple source tuple
     * @return type
     */
    String getType(ITuple tuple);

    /**
     * Extracts id from tuple.
     * @param tuple source tuple
     * @return id
     */
    String getId(ITuple tuple);

    /**
     * Extracts params from tuple if available.
     * @param tuple source tuple
     * @param defaultValue value to return if params are missing
     * @return params
     */
    Map<String, String> getParams(ITuple tuple, Map<String, String> defaultValue);
}
